% pdfMinEigBetaLaguerreTEST
%
% Tests the pdf of the smallest eigenvalue of a beta-Laguerre matrix 
% given as an expression in terms of the Hypergeometric Function of a
% Matrix Argument against the results of a Monte-Carlo experiment.
%
% Copyright (c) Plamen Koev, Massachusetts Institute of Technology.
% May 17, 2005, see COPYRIGHT.TXT for details.


set(0,... %'defaultaxesfontsize',12,
      'defaultaxeslinewidth',0.7, ...
      'defaultlinelinewidth',.8,'defaultpatchlinewidth',0.8);

n=5; beta=0.5; k=3; 
bins=40;

a=k+1+beta*(n-1)/2; % Technically a is the parameter, not k, but it is
                    % easier to choose k as a nonnegative integer instead 
                    % of a for the purposes of testing


nn=10000;               % # of trials

colormap(white);

r=zeros(1,nn);

   d=zeros(n,nn);
   l=zeros(n-1,nn);
   for i=1:n-1
      d(i+1,:)=sqrt(chi2rnd(2*a-beta*i,1,nn));
      l(i,:)=sqrt(chi2rnd(beta*(n-i),1,nn));
   end
   d(1,:)=sqrt(chi2rnd(2*a,1,nn));
   
   for j=1:nn
      z=svd(diag(d(:,j))+diag(l(:,j),1));
      r(j)=z(n)^2;
   end
    
   clf;
   hold off
   
   [N,X]=hist(r,bins);
   bar(X,N/sum(N)/(X(2)-X(1)));
   hold on;


   x=[1:bins]/4;

   s=pdfMinEigBetaLaguerre(25,beta,n,a,x);
  
   plot(x,s,'linewidth',2)
   hold on;

   xlabel('x');
   s=strcat('pdf of \lambda_m_i_n of (');
   s=strcat(s,num2str(n),'\times',...
     num2str(n),'), ',num2str(beta),'-Laguerre, a=',num2str(a));
   title(s);

